@@ -1,18 +1,17 @@
 import logging
+from asyncio import get_event_loop
 from pathlib import Path
 
 from pycrunch.api.serializers import serialize_test_set_state
-from pycrunch.api.shared import pipe, file_watcher
+from pycrunch.api.shared import file_watcher, pipe
+from pycrunch.discovery.strategy import create_test_discovery
 from pycrunch.introspection.history import execution_history
-from pycrunch.runner.execution_result import ExecutionResult
 from pycrunch.session import config
 from pycrunch.session.diagnostics import diagnostic_engine
 from pycrunch.shared.models import all_tests
 
 logger = logging.getLogger(__name__)
 
-from pycrunch.discovery.strategy import create_test_discovery
-
 class EngineState:
     def __init__(self):
         # self.all_tests = dict()
@@ -21,20 +20,17 @@ class EngineState:
         self.folder = folder_auto
         self.all_tests = all_tests
         self.runtime_configuration_ready = False
-        pass
-
-
 
     async def will_start_test_discovery(self):
-
+        #  TODO: How about running this automatically before engine is connected?
         self.prepare_runtime_configuration_if_necessary()
-
+        self.begin_watch_for_config_changes()
         discovery_engine = create_test_discovery()
         test_set = discovery_engine.find_tests_in_folder(self.folder)
         await engine.test_discovery_will_become_available(test_set)
 
-
-        pass
+    def begin_watch_for_config_changes(self):
+        config.watch_for_config_changes()
 
     async def will_start_diagnostics_collection(self):
         self.prepare_runtime_configuration_if_necessary()
@@ -54,15 +50,19 @@ class EngineState:
             is_pinned = config.is_test_pinned(discovered_test.fqn)
             self.all_tests.test_discovered(discovered_test.fqn, discovered_test, is_pinned)
 
+        # TODO: maybe do not wait for the signal from plugin to start discovery.
         self.all_tests.discard_tests_not_in_map()
-        await self.notify_clients_about_tests_change()
-        logger.info('discovery_did_become_available')
-        logger.info(f'Adding files for watch: total of {len(test_set.files)}')
+        self.notify_clients_about_tests_change()
+        logger.debug('discovery_did_become_available')
+        logger.debug(f'Adding files for watch: total of {len(test_set.files)}')
         file_watcher.watch(test_set.files)
 
-    async def notify_clients_about_tests_change(self):
-        logger.info('notify_clients_about_tests_change')
-        await pipe.push(event_type='discovery_did_become_available', **serialize_test_set_state(self.all_tests.tests), folder=self.folder)
+    def notify_clients_about_tests_change(self):
+        logger.debug('notify_clients_about_tests_change')
+        serialized_data = serialize_test_set_state(self.all_tests.tests)
+        get_event_loop().create_task(
+            pipe.push(event_type='discovery_did_become_available', **serialized_data, folder=self.folder)
+        )
 
     async def tests_will_run(self, tests):
         logger.info('tests_will_run')
@@ -70,18 +70,18 @@ class EngineState:
         for test in tests:
             self.all_tests.test_will_run(test.discovered_test.fqn)
 
-        await self.notify_clients_about_tests_change()
+        self.notify_clients_about_tests_change()
 
     async def tests_did_run(self, results):
         for k, v in results.items():
             self.all_tests.test_did_run(k, v)
 
-        await self.notify_clients_about_tests_change()
+        self.notify_clients_about_tests_change()
 
     async def tests_will_pin(self, fqns):
         for fqn in fqns:
             self.all_tests.pin_test(fqn)
-        await self.notify_clients_about_tests_change()
+        self.notify_clients_about_tests_change()
 
         self.save_pinned_state()
 
@@ -91,7 +91,7 @@ class EngineState:
             self.all_tests.unpin_test(fqn)
 
         self.save_pinned_state()
-        await self.notify_clients_about_tests_change()
+        self.notify_clients_about_tests_change()
 
     def save_pinned_state(self):
         config.save_pinned_tests_config(self.all_tests.get_pinned_tests())
