@@ -1,5 +1,7 @@
+import json
 import unittest
-from pprint import pprint
+import uuid
+import pprint
 from unittest.mock import MagicMock
 
 from pycrunch.api.serializers import CoverageRun
@@ -12,14 +14,36 @@ from pycrunch.shared.primitives import TestMetadata
 
 class TestCoverageRun(unittest.TestCase):
     def test_sample(self):
-        test_meta = TestMetadata('file1', 'test_a', 'module_a', 'module_a:test_a', 'queued')
+        test_meta = self.sample_metadata()
         state_timeline = InsightTimeline(clock=Clock())
 
         execution_result = ExecutionResult()
         execution_result.run_did_succeed()
         execution_result.state_timeline_did_become_available(state_timeline)
         run = CoverageRun('test1', 1, test_meta, execution_result)
-        pprint(run.as_json())
+        pprint.pprint(run.as_json())
+
+    def sample_metadata(self):
+        test_meta = TestMetadata('file1', 'test_a', 'module_a', 'module_a:test_a', 'queued')
+        return test_meta
+
+    def test_unsupported_type_uuid_in_state_timeline_dict(self):
+        state_timeline = InsightTimeline(clock=Clock())
+        state_timeline.start()
+
+        state_timeline.record(dict(some=uuid.uuid1()))
+        t = dict(a=1, nested=dict(some=uuid.uuid1()))
+        x = pprint.pformat(t)
+
+        state_timeline.record(t)
+        state_timeline.record(TestCoverageRun)
+        state_timeline.record(self)
+
+        execution_result = ExecutionResult()
+        execution_result.run_did_succeed()
+        execution_result.state_timeline_did_become_available(state_timeline)
+        x = json.dumps(state_timeline.as_json())
+        print(x)
 
     def test_coverage_lib_version_4(self):
         sut = self.create_sut(is_v5_or_greater=False)
@@ -35,6 +59,6 @@ class TestCoverageRun(unittest.TestCase):
         assert actual['data_file'] == None
 
     def create_sut(self, is_v5_or_greater):
-        sut = CoverageAbstraction(True, None)
+        sut = CoverageAbstraction(True, None, None)
         sut.is_coverage_v5_or_greater = MagicMock(return_value=is_v5_or_greater)
         return sut
